pub struct Hooks {
pub log_fn: Arc<dyn Fn(CommunicationSetup) -> Option<Logger<CommunicationEventBuilder>> + Send + Sync>,
pub refill: BytesRefill,
pub spill: Option<SpillPolicyFn>,
}Expand description
Configuration hooks that (currently) live outside the configuration.
Fields are public so callers can mutate Hooks::default() before
passing it to try_build_with.
Fields
log_fn: Arc<dyn Fn(CommunicationSetup) -> Option<Logger<CommunicationEventBuilder>> + Send + Sync>A mechanism to set up loggers for each communication thread.
refill: BytesRefillA strategy for refreshing bytes for BytesSlab.
spill: Option<SpillPolicyFn>A mechanism to get a matched pair of spill policies (writer, reader) per queue.