Bytesable

Trait Bytesable 

pub trait Bytesable {
    // Required methods
    fn from_bytes(bytes: Bytes) -> Self;
    fn length_in_bytes(&self) -> usize;
    fn into_bytes<W: Write>(&self, writer: &mut W);
}
A type that can be serialized and deserialized through Bytes.

Required Methods

fn from_bytes(bytes: Bytes) -> Self

Wrap bytes as Self.

fn length_in_bytes(&self) -> usize

The number of bytes required to serialize the data.

fn into_bytes<W: Write>(&self, writer: &mut W)

Writes the binary representation into writer.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors