pub struct ProcessBuilder { /* private fields */ }Expand description
Builds an instance of a ProcessAllocator.
Builders are required because some of the state in a ProcessAllocator cannot be sent between
threads (specifically, the Rc<RefCell<_>> local channels). So, we must package up the state
shared between threads here, and then provide a method that will instantiate the non-movable
members once in the destination thread.
Implementations
Sourceimpl ProcessBuilder
impl ProcessBuilder
Sourcepub fn build(self) -> ProcessAllocator
pub fn build(self) -> ProcessAllocator
Builds a ProcessAllocator, instantiating Rc<RefCell<_>> elements.